@@ -23,7 +23,7 @@
 #ifdef __KDE_HAVE_GCC_VISIBILITY
 #define PLUGIN_NO_EXPORT __attribute__ ((visibility("hidden")))
 #define PLUGIN_EXPORT __attribute__ ((visibility("default")))
-#elif defined(Q_WS_WIN)
+#elif defined(TQ_WS_WIN)
 #define PLUGIN_NO_EXPORT
 #define PLUGIN_EXPORT __declspec(dllexport)
 #else
